searchNodes=[{"ref":"Mix.Tasks.Que.Setup.html","title":"Mix.Tasks.Que.Setup","type":"task","doc":"Creates an Mnesia DB on disk for Que Que works out of the box without any configuration needed, but initially all Jobs are not persisted to disk, and are only in memory. You&#39;ll need to create the Mnesia Schema on disk and create the Job Database for this to work. This Mix Task lets you do that. You should first specify the database location in your config.exs file. It&#39;s highly recommended that you include Mix.env in the path to keep development, test and production databases separate. config :mnesia, dir: &#39;mnesia/\#{Mix.env}/\#{node()}&#39; # Notice the single quotes You can now run the Mix Task: $ mix que.setup Production For production environments and compiled releases where Mix is not available, you should use Que.Persistence.Mnesia.setup!/0 instead. You can read about it here. Custom Node Name and Cookie If you need to specify the node name and cookie for the task, you can call it like this: $ elixir --name &lt;node_name&gt; --cookie &lt;cookie&gt; -S mix que.setup Source: elixir-lang-talk"},{"ref":"Que.html","title":"Que","type":"module","doc":"Que is a simple background job processing library backed by Mnesia. Que doesn&#39;t depend on any external services like Redis for persisting job state, instead uses the built-in erlang application mnesia. This makes it extremely easy to use as you don&#39;t need to install anything other than Que itself. Installation First add it as a dependency in your mix.exs and run mix deps.get: defp deps do [{:que, &quot;~&gt; 0.10.0&quot;}] end Then run $ mix deps.get and add it to your list of applications: def application do [applications: [:que]] end Usage Define a Worker to process your jobs: defmodule App.Workers.ImageConverter do use Que.Worker def perform(image) do ImageTool.save_resized_copy!(image, :thumbnail) ImageTool.save_resized_copy!(image, :medium) ImageTool.save_resized_copy!(image, :large) end end You can now add jobs to be processed by the worker: Que.add(App.Workers.ImageConverter, some_image) #=&gt; :ok Read the Que.Worker documentation for other callbacks and concurrency options. Persist to Disk By default, Que uses an in-memory Mnesia database so jobs are NOT persisted across application restarts. To do that, you first need to specify a path for your mnesia database in you config.exs. config :mnesia, dir: &#39;mnesia/\#{Mix.env}/\#{node()}&#39; # Notice the single quotes You can now call the que.setup mix task to create the job database: $ mix que.setup For compiled releases, see the Que.Persistence.Mnesia documentation."},{"ref":"Que.html#add/2","title":"Que.add/2","type":"function","doc":"Enqueues a Job to be processed by Que. Accepts the worker module name and a term to be passed to the worker as arguments. Example Que.add(App.Workers.FileDownloader, {&quot;http://example.com/file/path.zip&quot;, &quot;/some/local/path.zip&quot;}) #=&gt; :ok Que.add(App.Workers.SignupMailer, to: &quot;some@email.com&quot;, message: &quot;Thank you for Signing up!&quot;) #=&gt; :ok"},{"ref":"Que.html#start/2","title":"Que.start/2","type":"function","doc":"Starts the Que Application (and its Supervision Tree)"},{"ref":"Que.Job.html","title":"Que.Job","type":"module","doc":"Module to manage a Job&#39;s state and execute the worker&#39;s callbacks. Defines a Que.Job struct an keeps track of the Job&#39;s worker, arguments, status and more. Meant for internal usage, so you shouldn&#39;t use this unless you absolutely know what you&#39;re doing."},{"ref":"Que.Job.html#handle_failure/2","title":"Que.Job.handle_failure/2","type":"function","doc":"Handles Job Failure, Calls appropriate worker method and updates the job status to :failed"},{"ref":"Que.Job.html#handle_success/1","title":"Que.Job.handle_success/1","type":"function","doc":"Handles Job Success, Calls appropriate worker method and updates the job status to :completed"},{"ref":"Que.Job.html#new/2","title":"Que.Job.new/2","type":"function","doc":"Returns a new Job struct with defaults"},{"ref":"Que.Job.html#perform/1","title":"Que.Job.perform/1","type":"function","doc":"Updates the Job struct with new status and spawns &amp; monitors a new Task under the TaskSupervisor which executes the perform method with supplied arguments"},{"ref":"Que.Job.html#set_status/2","title":"Que.Job.set_status/2","type":"function","doc":"Update the Job status to one of the predefined values in @statuses"},{"ref":"Que.Job.html#t:status/0","title":"Que.Job.status/0","type":"type","doc":"One of the atoms in [:queued, :started, :failed, :completed]"},{"ref":"Que.Job.html#t:t/0","title":"Que.Job.t/0","type":"type","doc":"A Que.Job struct"},{"ref":"Que.Persistence.html","title":"Que.Persistence","type":"behaviour","doc":"Provides a high-level API to interact with Jobs in Database This module is a behaviour that delegates calls to the specified adapter. It has been designed in a way that it&#39;s easy to write custom adapters for other databases or stores like Redis, even though there are no current plans on supporting anything other than Mnesia."},{"ref":"Que.Persistence.html#all/0","title":"Que.Persistence.all/0","type":"function","doc":"See Que.Persistence.Mnesia.all/0."},{"ref":"Que.Persistence.html#c:all/0","title":"Que.Persistence.all/0","type":"callback","doc":"Returns all Que.Jobs in the database."},{"ref":"Que.Persistence.html#all/1","title":"Que.Persistence.all/1","type":"function","doc":"See Que.Persistence.Mnesia.all/1."},{"ref":"Que.Persistence.html#c:all/1","title":"Que.Persistence.all/1","type":"callback","doc":"Returns all Que.Jobs for the given worker."},{"ref":"Que.Persistence.html#completed/0","title":"Que.Persistence.completed/0","type":"function","doc":"See Que.Persistence.Mnesia.completed/0."},{"ref":"Que.Persistence.html#c:completed/0","title":"Que.Persistence.completed/0","type":"callback","doc":"Returns completed Que.Jobs from the database."},{"ref":"Que.Persistence.html#completed/1","title":"Que.Persistence.completed/1","type":"function","doc":"See Que.Persistence.Mnesia.completed/1."},{"ref":"Que.Persistence.html#c:completed/1","title":"Que.Persistence.completed/1","type":"callback","doc":"Returns completed Que.Jobs for the given worker."},{"ref":"Que.Persistence.html#destroy/1","title":"Que.Persistence.destroy/1","type":"function","doc":"See Que.Persistence.Mnesia.destroy/1."},{"ref":"Que.Persistence.html#c:destroy/1","title":"Que.Persistence.destroy/1","type":"callback","doc":"Deletes a Que.Job from the database."},{"ref":"Que.Persistence.html#failed/0","title":"Que.Persistence.failed/0","type":"function","doc":"See Que.Persistence.Mnesia.failed/0."},{"ref":"Que.Persistence.html#c:failed/0","title":"Que.Persistence.failed/0","type":"callback","doc":"Returns failed Que.Jobs from the database."},{"ref":"Que.Persistence.html#failed/1","title":"Que.Persistence.failed/1","type":"function","doc":"See Que.Persistence.Mnesia.failed/1."},{"ref":"Que.Persistence.html#c:failed/1","title":"Que.Persistence.failed/1","type":"callback","doc":"Returns failed Que.Jobs for the given worker."},{"ref":"Que.Persistence.html#find/1","title":"Que.Persistence.find/1","type":"function","doc":"See Que.Persistence.Mnesia.find/1."},{"ref":"Que.Persistence.html#c:find/1","title":"Que.Persistence.find/1","type":"callback","doc":"Finds a Que.Job from the database. Returns the a Job struct if it&#39;s found, otherwise nil."},{"ref":"Que.Persistence.html#incomplete/0","title":"Que.Persistence.incomplete/0","type":"function","doc":"See Que.Persistence.Mnesia.incomplete/0."},{"ref":"Que.Persistence.html#c:incomplete/0","title":"Que.Persistence.incomplete/0","type":"callback","doc":"Returns incomplete Que.Jobs from the database. This includes all Jobs whose status is either :queued or :started but not :failed."},{"ref":"Que.Persistence.html#incomplete/1","title":"Que.Persistence.incomplete/1","type":"function","doc":"See Que.Persistence.Mnesia.incomplete/1."},{"ref":"Que.Persistence.html#c:incomplete/1","title":"Que.Persistence.incomplete/1","type":"callback","doc":"Returns incomplete Que.Jobs for the given worker."},{"ref":"Que.Persistence.html#initialize/0","title":"Que.Persistence.initialize/0","type":"function","doc":"See Que.Persistence.Mnesia.initialize/0."},{"ref":"Que.Persistence.html#c:initialize/0","title":"Que.Persistence.initialize/0","type":"callback","doc":"Makes sure that the Database is ready to be used. This is called when the Que application, specifically Que.Server, starts to make sure that a database exists and is ready to be used."},{"ref":"Que.Persistence.html#insert/1","title":"Que.Persistence.insert/1","type":"function","doc":"See Que.Persistence.Mnesia.insert/1."},{"ref":"Que.Persistence.html#c:insert/1","title":"Que.Persistence.insert/1","type":"callback","doc":"Inserts a Que.Job into the database. Returns the same Job struct with the id value set"},{"ref":"Que.Persistence.html#update/1","title":"Que.Persistence.update/1","type":"function","doc":"See Que.Persistence.Mnesia.update/1."},{"ref":"Que.Persistence.html#c:update/1","title":"Que.Persistence.update/1","type":"callback","doc":"Updates an existing Que.Job in the database. This methods finds the job to update by the given job&#39;s id. If no job with the given id exists, it is inserted as-is. If the id of the given job is nil, it&#39;s still inserted and a valid id is assigned. Returns the updated job."},{"ref":"Que.Persistence.Mnesia.html","title":"Que.Persistence.Mnesia","type":"module","doc":"Mnesia adapter to persist Que.Jobs This module defines a Database and a Job Table in Mnesia to keep track of all Jobs, along with Mnesia transaction methods that provide an easy way to find, insert, update or destroy Jobs from the Database. It implements all callbacks defined in Que.Persistence, along with some Mnesia specific ones. You should read the Que.Persistence documentation if you just want to interact with the Jobs in database. Persisting to Disk Que works out of the box without any configuration needed, but initially all Jobs are not persisted to disk, and are only in memory. You&#39;ll need to create the Mnesia Schema on disk and create the Job Database for this to work. Que provides ways that automatically do this for you. First, specify the location where you want your Mnesia database to be created in your config.exs file. It&#39;s highly recommended that you specify your Mix.env in the path to keep development, test and production databases separate. config :mnesia, dir: &#39;mnesia/\#{Mix.env}/\#{node()}&#39; # Notice the single quotes You can now either run the Mix.Tasks.Que.Setup mix task or call Que.Persistence.Mnesia.setup!/0 to create the Schema, Database and Tables."},{"ref":"Que.Persistence.Mnesia.html#__config__/0","title":"Que.Persistence.Mnesia.__config__/0","type":"function","doc":"Returns the Mnesia configuration for Que"},{"ref":"Que.Persistence.Mnesia.html#setup!/1","title":"Que.Persistence.Mnesia.setup!/1","type":"function","doc":"Creates the Mnesia Database for Que on disk This creates the Schema, Database and Tables for Que Jobs on disk for the specified erlang nodes so Jobs are persisted across application restarts. Calling this momentarily stops the :mnesia application so you should make sure it&#39;s not being used when you do. If no argument is provided, the database is created for the current node. On Production For a compiled release (Distillery or Exrm), start the application in console mode or connect a shell to the running release and simply call the method: $ bin/my_app remote_console iex(my_app@127.0.0.1)1&gt; Que.Persistence.Mnesia.setup! :ok You can alternatively provide a list of nodes for which you would like to create the schema: iex(my_app@host_x)1&gt; nodes = [node() | Node.list] [:my_app@host_x, :my_app@host_y, :my_app@host_z] iex(my_app@node_x)2&gt; Que.Persistence.Mnesia.setup!(nodes) :ok"},{"ref":"Que.Queue.html","title":"Que.Queue","type":"module","doc":"Module to manage a Queue comprising of multiple jobs. Responsible for queueing (duh), executing and handling callbacks, for Que.Jobs of a specific Que.Worker. Also keeps track of running jobs and processes them concurrently (if the worker is configured so). Meant for internal usage, so you shouldn&#39;t use this unless you absolutely know what you&#39;re doing."},{"ref":"Que.Queue.html#fetch/1","title":"Que.Queue.fetch/1","type":"function","doc":"Fetches the next Job in queue and returns a queue and Job tuple"},{"ref":"Que.Queue.html#find/3","title":"Que.Queue.find/3","type":"function","doc":"Finds the Job in Queue by the specified key name and value. If no key is specified, it&#39;s assumed to be an :id. If the specified key is a :ref, it only searches in the :running list."},{"ref":"Que.Queue.html#new/2","title":"Que.Queue.new/2","type":"function","doc":"Returns a new processable Queue with defaults"},{"ref":"Que.Queue.html#process/1","title":"Que.Queue.process/1","type":"function","doc":"Processes the Queue and runs pending jobs"},{"ref":"Que.Queue.html#put/2","title":"Que.Queue.put/2","type":"function","doc":"Adds one or more Jobs to the queued list"},{"ref":"Que.Queue.html#queued/1","title":"Que.Queue.queued/1","type":"function","doc":"Returns queued jobs in the Queue"},{"ref":"Que.Queue.html#remove/2","title":"Que.Queue.remove/2","type":"function","doc":"Removes the specified Job from running"},{"ref":"Que.Queue.html#running/1","title":"Que.Queue.running/1","type":"function","doc":"Returns running jobs in the Queue"},{"ref":"Que.Queue.html#update/2","title":"Que.Queue.update/2","type":"function","doc":"Finds a Job in the Queue by the given Job&#39;s id, replaces it and returns an updated Queue"},{"ref":"Que.Queue.html#t:t/0","title":"Que.Queue.t/0","type":"type","doc":"A Que.Queue struct"},{"ref":"Que.Server.html","title":"Que.Server","type":"module","doc":"Que.Server is the GenServer responsible for processing all Jobs. This GenServer oversees the Workers performing their Jobs and handles their success and failure callbacks. You shouldn&#39;t call any of this module&#39;s methods directly. Instead use the methods exported by the base Que module."},{"ref":"Que.Server.html#child_spec/1","title":"Que.Server.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"Que.Server.html#start_link/1","title":"Que.Server.start_link/1","type":"function","doc":"Starts the Job Server"},{"ref":"Que.Server.html#stop/1","title":"Que.Server.stop/1","type":"function","doc":"Stops the Job Server"},{"ref":"Que.ServerSupervisor.html","title":"Que.ServerSupervisor","type":"module","doc":"This Supervisor is responsible for spawning a Que.Server for each worker. You shouldn&#39;t start this manually unless you absolutely know what you&#39;re doing."},{"ref":"Que.ServerSupervisor.html#child_spec/1","title":"Que.ServerSupervisor.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"Que.ServerSupervisor.html#start_link/0","title":"Que.ServerSupervisor.start_link/0","type":"function","doc":"Starts the Supervision Tree"},{"ref":"Que.ServerSupervisor.html#start_server/1","title":"Que.ServerSupervisor.start_server/1","type":"function","doc":"Starts a Que.Server for the given worker"},{"ref":"Que.Supervisor.html","title":"Que.Supervisor","type":"module","doc":"This is the Supervisor responsible for overseeing the entire Que application. You shouldn&#39;t start this manually unless you absolutely know what you&#39;re doing."},{"ref":"Que.Supervisor.html#child_spec/1","title":"Que.Supervisor.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"Que.Supervisor.html#start_link/0","title":"Que.Supervisor.start_link/0","type":"function","doc":"Starts the Supervision Tree for Que"},{"ref":"Que.Worker.html","title":"Que.Worker","type":"behaviour","doc":"Defines a Worker for processing Jobs. The defined worker is responsible for processing passed jobs, and handling the job&#39;s success and failure callbacks. The defined worker must export a perform/1 callback otherwise compilation will fail. Basic Worker defmodule MyApp.Workers.SignupMailer do use Que.Worker def perform(email) do Mailer.send_email(to: email, message: &quot;Thank you for signing up!&quot;) end end You can also pattern match and use guard clauses like normal methods: defmodule MyApp.Workers.NotificationSender do use Que.Worker def perform(type: :like, to: user, count: count) do User.notify(user, &quot;You have \#{count} new likes on your posts&quot;) end def perform(type: :message, to: user, from: sender) do User.notify(user, &quot;You received a new message from \#{sender.name}&quot;) end def perform(to: user) do User.notify(user, &quot;New activity on your profile&quot;) end end Concurrency By default, workers process one Job at a time. You can specify a custom value by passing the concurrency option. defmodule MyApp.Workers.PageScraper do use Que.Worker, concurrency: 4 def perform(url), do: Scraper.scrape(url) end If you want all Jobs to be processed concurrently without any limit, you can set the concurrency option to :infinity. The concurrency option must either be a positive integer or :infinity, otherwise it will raise an error during compilation. Handle Job Success &amp; Failure The worker can also export optional on_success/1 and on_failure/2 callbacks that handle appropriate cases. defmodule MyApp.Workers.CampaignMailer do use Que.Worker def perform({campaign, user}) do Mailer.send_campaign_email(campaign, user: user) end def on_success({campaign, user}) do CampaignReport.compile(campaign, status: :success, user: user) end def on_failure({campaign, user}, error) do CampaignReport.compile(campaign, status: :failed, user: user) Logger.debug(&quot;Campaign email to \#{user.id} failed: \#{inspect(error)}&quot;) end end Setup and Teardown You can similarly export optional on_setup/1 and on_teardown/1 callbacks that are respectively run before and after the job is performed (successfully or not). defmodule MyApp.Workers.VideoProcessor do use Que.Worker def on_setup({user, _video, _options}) do User.notify(user, &quot;Your video is processing, check back later.&quot;) end def perform({_user, video, options}) do FFMPEG.process(video.path, options) end def on_teardown({user, video, _options}) do link = MyApp.Router.video_path(user.id, video.id) User.notify(user, &quot;We&#39;ve finished processing your video. See the results.&quot;, link) end end Failed Job Retries Failed Jobs are NOT automatically retried. If you want a job to be retried when it fails, you can simply enqueue it again. To get a list of all failed jobs, you can call Que.Persistence.failed/0."},{"ref":"Que.Worker.html#c:on_failure/2","title":"Que.Worker.on_failure/2","type":"callback","doc":"Optional callback that is executed if an error is raised during job is processed (in perform callback)"},{"ref":"Que.Worker.html#c:on_setup/1","title":"Que.Worker.on_setup/1","type":"callback","doc":"Optional callback that is executed before the job is started."},{"ref":"Que.Worker.html#c:on_success/1","title":"Que.Worker.on_success/1","type":"callback","doc":"Optional callback that is executed when the job is processed successfully."},{"ref":"Que.Worker.html#c:on_teardown/1","title":"Que.Worker.on_teardown/1","type":"callback","doc":"Optional callback that is executed after the job finishes, both on success and failure."},{"ref":"Que.Worker.html#c:perform/1","title":"Que.Worker.perform/1","type":"callback","doc":"Main callback that processes the Job. This is a required callback that must be implemented by the worker. If the worker doesn&#39;t export perform/1 method, compilation will fail. It takes one argument which is whatever that&#39;s passed to Que.add. You can define it like any other method, use guard clauses and also use pattern matching with multiple method definitions."},{"ref":"Que.Worker.html#valid?/1","title":"Que.Worker.valid?/1","type":"function","doc":"Checks if the specified module is a valid Que Worker Example defmodule MyWorker do use Que.Worker def perform(_args), do: nil end Que.Worker.valid?(MyWorker) # =&gt; true Que.Worker.valid?(SomeOtherModule) # =&gt; false"},{"ref":"Que.Worker.html#validate!/1","title":"Que.Worker.validate!/1","type":"function","doc":"Raises an error if the passed module is not a valid Que.Worker"},{"ref":"Que.Worker.html#t:t/0","title":"Que.Worker.t/0","type":"type","doc":"A valid worker module"},{"ref":"readme.html","title":"","type":"extras","doc":"![Build Status][shield-travis]][travis-ci] [![Coverage Status][shield-inch]][docs] [![Version][shield-version]][hexpm] [![License][shield-license] Simple Background Job Processing in Elixir :zap: Que is a job processing library backed by Mnesia, a distributed real-time database that comes with Erlang / Elixir. That means it doesn&#39;t depend on any external services like Redis for persisting job state. This makes it really easy to use since you don&#39;t need to install anything other than Que itself. See the Documentation."},{"ref":"readme.html#installation","title":" - Installation","type":"extras","doc":"Add que to your project dependencies in mix.exs: def deps do [{:que, &quot;~&gt; 0.10.0&quot;}] end and then add it to your list of applications: def application do [applications: [:que]] end Mnesia Setup Que runs out of the box, but by default all jobs are stored in-memory. To persist jobs across application restarts, specify the DB path in your config.exs: config :mnesia, dir: &#39;mnesia/\#{Mix.env}/\#{node()}&#39; # Notice the single quotes And run the following mix task: $ mix que.setup This will create the Mnesia schema and job database for you. For a detailed guide, see the Mix Task Documentation. For compiled releases where Mix is not available see this."},{"ref":"readme.html#usage","title":" - Usage","type":"extras","doc":"Que is very similar to other job processing libraries such as Ku and Toniq. Start by defining a Worker with a perform/1 callback to process your jobs: defmodule App.Workers.ImageConverter do use Que.Worker def perform(image) do ImageTool.save_resized_copy!(image, :thumbnail) ImageTool.save_resized_copy!(image, :medium) end end You can now add jobs to be processed by the worker: Que.add(App.Workers.ImageConverter, some_image) #=&gt; {:ok, %Que.Job{...}} Pattern Matching The argument here can be any term from a Tuple to a Keyword List or a Struct. You can also pattern match and use guard clauses like any other method: defmodule App.Workers.NotificationSender do use Que.Worker def perform(type: :like, to: user, count: count) do User.notify(user, &quot;You have \#{count} new likes on your posts&quot;) end def perform(type: :message, to: user, from: sender) do User.notify(user, &quot;You received a new message from \#{sender.name}&quot;) end def perform(to: user) do User.notify(user, &quot;New activity on your profile&quot;) end end Concurrency By default, all workers process one Job at a time, but you can customize that by passing the concurrency option: defmodule App.Workers.SignupMailer do use Que.Worker, concurrency: 4 def perform(email) do Mailer.send_email(to: email, message: &quot;Thank you for signing up!&quot;) end end Job Success / Failure Callbacks The worker can also export optional on_success/1 and on_failure/2 callbacks that handle appropriate cases. defmodule App.Workers.ReportBuilder do use Que.Worker def perform({user, report}) do report.data |&gt; PDFGenerator.generate! |&gt; File.write!(&quot;reports/\#{user.id}/report-\#{report.id}.pdf&quot;) end def on_success({user, _}) do Mailer.send_email(to: user.email, subject: &quot;Your Report is ready!&quot;) end def on_failure({user, report}, error) do Mailer.send_email(to: user.email, subject: &quot;There was a problem generating your report&quot;) Logger.error(&quot;Could not generate report \#{report.id}. Reason: \#{inspect(error)}&quot;) end end Setup and Teardown You can similarly export optional on_setup/1 and on_teardown/1 callbacks that are respectively run before and after the job is performed (successfully or not). defmodule App.Workers.VideoProcessor do use Que.Worker def on_setup({user, _video, _options}) do User.notify(user, &quot;Your video is processing, check back later.&quot;) end def perform({_user, video, options}) do FFMPEG.process(video.path, options) end def on_teardown({user, video, _options}) do link = Router.video_path(user.id, video.id) User.notify(user, &quot;We&#39;ve finished processing your video. See the results.&quot;, link) end end Head over to Hexdocs for detailed Worker documentation."},{"ref":"readme.html#roadmap","title":" - Roadmap","type":"extras","doc":"[x] Write Documentation [x] Write Tests [x] Persist Job State to Disk [x] Provide an API to interact with Jobs [x] Add Concurrency Support [x] Make jobs work in Parallel [x] Allow customizing the number of concurrent jobs [x] Success/Failure Callbacks [x] Find a more reliable replacement for Amnesia [ ] Delayed Jobs [ ] Allow job cancellation [ ] Job Priority [ ] Support running in a multi-node enviroment [ ] Recover from node failures [ ] Support for more Persistence Adapters [ ] Redis [ ] Postgres [x] Mix Task for creating Mnesia Database [ ] Better Job Failures [ ] Option to set timeout on workers [ ] Add strategies to automatically retry failed jobs [ ] Web UI"},{"ref":"readme.html#contributing","title":" - Contributing","type":"extras","doc":"Fork, Enhance, Send PR Lock issues with any bugs or feature requests Implement something from Roadmap Spread the word :heart:"},{"ref":"readme.html#license","title":" - License","type":"extras","doc":"This package is available as open source under the terms of the MIT License."}]